@@ -130,8 +130,8 @@ static int set_option_srv(char const *filename, int line, OPTION *option, char c
 	p_pointer = strtok_r(p_dupe, ", \t", &p_save);
 
         while(p_pointer != NULL) {
-                if (serv->max > SERVER_MAX) {
-                        DEBUG(LOG_ERR, "cannot set more than %d servers", SERVER_MAX);
+                if (serv->max > RC_SERVER_MAX) {
+                        DEBUG(LOG_ERR, "cannot set more than %d servers", RC_SERVER_MAX);
                         goto fail;
                 }
 
@@ -714,7 +714,7 @@ char *rc_conf_str(rc_handle const *rh, char const *optname)
 	if (option != NULL) {
 		return (char *)option->val;
 	} else {
-		rc_log(LOG_CRIT, "rc_conf_str: unkown config option requested: %s", optname);
+		rc_log(LOG_CRIT, "rc_conf_str: unknown config option requested: %s", optname);
 		return NULL;
 	}
 }
@@ -739,7 +739,7 @@ static int rc_conf_int_2(rc_handle const *rh, char const *optname, int complain)
 		}
                 return 0;
 	} else {
-		rc_log(LOG_CRIT, "rc_conf_int: unkown config option requested: %s", optname);
+		rc_log(LOG_CRIT, "rc_conf_int: unknown config option requested: %s", optname);
 		return 0;
 	}
 }
@@ -764,7 +764,7 @@ SERVER *rc_conf_srv(rc_handle const *rh, char const *optname)
 	if (option != NULL) {
 		return (SERVER *)option->val;
 	} else {
-		rc_log(LOG_CRIT, "rc_conf_srv: unkown config option requested: %s", optname);
+		rc_log(LOG_CRIT, "rc_conf_srv: unknown config option requested: %s", optname);
 		return NULL;
 	}
 }
@@ -1061,7 +1061,7 @@ int rc_find_server_addr (rc_handle const *rh, char const *server_name,
  */
 void rc_config_free(rc_handle *rh)
 {
-	int i;
+	int i, j;
 	SERVER *serv;
 
 	if (rh->config_options == NULL)
@@ -1071,9 +1071,11 @@ void rc_config_free(rc_handle *rh)
 		if (rh->config_options[i].val == NULL)
 			continue;
 		if (rh->config_options[i].type == OT_SRV) {
-		        serv = (SERVER *)rh->config_options[i].val;
-			free(serv->name[0]);
-			if(serv->secret[0]) free(serv->secret[0]);
+			serv = (SERVER *)rh->config_options[i].val;
+			for (j = 0; j < serv->max; j++) {
+				free(serv->name[j]);
+				if(serv->secret[j]) free(serv->secret[j]);
+			}
 			free(serv);
 		} else {
 			free(rh->config_options[i].val);
