@@ -56,7 +56,7 @@ static int rc_pack_list(VALUE_PAIR * vp, char *secret, AUTH_HDR * auth)
 	int total_length = 0;
 	size_t secretlen;
 	uint32_t lvalue, vendor;
-	unsigned char passbuf[MAX(AUTH_PASS_LEN, CHAP_VALUE_LENGTH)];
+	unsigned char passbuf[RC_MAX(AUTH_PASS_LEN, CHAP_VALUE_LENGTH)];
 	unsigned char md5buf[256];
 	unsigned char *buf, *vector, *vsa_length_ptr;
 
@@ -109,7 +109,7 @@ static int rc_pack_list(VALUE_PAIR * vp, char *secret, AUTH_HDR * auth)
 				rc_md5_calc(buf, md5buf,
 					    secretlen + AUTH_VECTOR_LEN);
 
-				/* Remeber the start of the digest */
+				/* Remember the start of the digest */
 				vector = buf;
 
 				/* Xor the password into the MD5 digest */
@@ -226,7 +226,7 @@ static int populate_ctx(RC_AAA_CTX ** ctx, char secret[MAX_SECRET_LENGTH + 1],
  * @param msg must be an array of %PW_MAX_MSG_SIZE or NULL; will contain the concatenation of
  *	any %PW_REPLY_MESSAGE received.
  * @param type must be %AUTH or %ACCT
- * @return OK_RC (0) on success, TIMEOUT_RC on timeout REJECT_RC on acess reject, or negative
+ * @return OK_RC (0) on success, TIMEOUT_RC on timeout REJECT_RC on access reject, or negative
  *	on failure as return value.
  */
 int rc_send_server(rc_handle * rh, SEND_DATA * data, char *msg, rc_type type)
@@ -421,7 +421,7 @@ static int add_msg_auth_attr(rc_handle * rh, char * secret,
 	total_length += 18;
 	auth->length = htons((unsigned short)total_length);
 
-	/* Calulate HMAC-MD5 [RFC2104] hash */
+	/* Calculate HMAC-MD5 [RFC2104] hash */
 	uint8_t digest[MD5_DIGEST_SIZE];
 	rc_hmac_md5((uint8_t *)auth, (size_t)total_length, (uint8_t *)secret, secretlen, digest);
 	memcpy(&msg_auth[2], digest, MD5_DIGEST_SIZE);
@@ -459,8 +459,8 @@ int rc_send_server_ctx(rc_handle * rh, RC_AAA_CTX ** ctx, SEND_DATA * data,
 	size_t secretlen;
 	char secret[MAX_SECRET_LENGTH + 1];
 	unsigned char vector[AUTH_VECTOR_LEN];
-	uint8_t recv_buffer[BUFFER_LEN];
-	uint8_t send_buffer[BUFFER_LEN];
+	uint8_t recv_buffer[RC_BUFFER_LEN];
+	uint8_t send_buffer[RC_BUFFER_LEN];
 	uint8_t *attr;
 	uint16_t tlen;
 	int retries;
@@ -541,11 +541,10 @@ int rc_send_server_ctx(rc_handle * rh, RC_AAA_CTX ** ctx, SEND_DATA * data,
 	      server_name);
 	if (discover_local_ip) {
 		result = rc_get_srcaddr(SA(&our_sockaddr), auth_addr->ai_addr);
-		if (result != 0) {
+		if (result != OK_RC) {
 			memset(secret, '\0', sizeof(secret));
 			rc_log(LOG_ERR,
 			       "rc_send_server: cannot figure our own address");
-			result = ERROR_RC;
 			goto cleanup;
 		}
 	}
@@ -703,9 +702,9 @@ int rc_send_server_ctx(rc_handle * rh, RC_AAA_CTX ** ctx, SEND_DATA * data,
 					   auth_addr->ai_addrlen);
 		} while (result == -1 && errno == EINTR);
 		if (result == -1) {
+			result = errno == ENETUNREACH ? NETUNREACH_RC : ERROR_RC;
 			rc_log(LOG_ERR, "%s: socket: %s", __FUNCTION__,
 			       strerror(errno));
-			result = ERROR_RC;
 			goto cleanup;
 		}
 
@@ -769,7 +768,7 @@ int rc_send_server_ctx(rc_handle * rh, RC_AAA_CTX ** ctx, SEND_DATA * data,
 			}
 
 			result =
-			    rc_check_reply(recv_auth, BUFFER_LEN, secret,
+			    rc_check_reply(recv_auth, RC_BUFFER_LEN, secret,
 					   vector, data->seq_nbr);
 			if (result != BADRESPID_RC) {
 				/* if a message that doesn't match our ID was received, then ignore
